DebugRunResult

Enum DebugRunResult 

pub enum DebugRunResult {
    Finished,
    HostcallError,
    EpochYield,
    CaughtExceptionThrown(OwnedRooted<ExnRef>),
    UncaughtExceptionThrown(OwnedRooted<ExnRef>),
    Trap(Trap),
    Breakpoint,
}
The result of one call to Debuggee::run().

This is similar to DebugEvent but without the lifetime, so it can be sent across async tasks, and incorporates the possibility of completion (Finished) as well.

Variants



Finished

Execution of the inner body finished.



HostcallError

An error was raised by a hostcall.



EpochYield

Wasm execution was interrupted by an epoch change.



CaughtExceptionThrown(OwnedRooted<ExnRef>)

An exception is thrown and caught by Wasm. The current state is at the throw-point.



UncaughtExceptionThrown(OwnedRooted<ExnRef>)

An exception was not caught and is escaping to the host.



Trap(Trap)

A Wasm trap occurred.



Breakpoint

A breakpoint was reached.