Module wit

Module wit 

Structs

Debuggee
A debuggee consisting of one Store over which we have debugging control.
EventFuture
A future that represents asynchronous execution of the debuggee until the next debug event pausing execution.
Frame
Representation of a frame within a debuggee.
Global
A WebAssembly global value which can be read and written to.
InjectCall
A function call to be injected upon resumption.
Instance
An instantiated WebAssembly module.
Memory
A WebAssembly linear memory.
Module
A compiled WebAssembly module, ready to be instantiated.
Table
A WebAssembly table, or an array of values.
WasmException
Representation of a Wasm exception object.
WasmFunc
A WebAssembly function which can be called.
WasmTag
A WebAssembly tag.

Enums

Error
Event
A debug event.
ResumptionValue
A resumption value indicates how we want to continue execution after a pause.
WasmType
WasmValue
Representation of a Wasm value.

Traits

Host
HostDebuggee
HostDebuggeeWithStore
HostEventFuture
HostEventFutureWithStore
HostFrame
HostFrameWithStore
HostGlobal
HostGlobalWithStore
HostInstance
HostInstanceWithStore
HostMemory
HostMemoryWithStore
HostModule
HostModuleWithStore
HostTable
HostTableWithStore
HostWasmException
HostWasmExceptionWithStore
HostWasmFunc
HostWasmFuncWithStore
HostWasmTag
HostWasmTagWithStore
HostWasmValue
HostWasmValueWithStore
HostWithStore

Functions

add_to_linker

Type Aliases

Pollable