pub enum Event {
Complete,
Trap,
Breakpoint,
Interrupted,
CaughtExceptionThrown(Resource<WasmException>),
UncaughtExceptionThrown(Resource<WasmException>),
InjectedCallReturn(Vec<Resource<WasmValue>>),
}Expand description
A debug event.
Variants
Complete
Execution of the debuggee has completed.
Trap
A trap occurred in the debuggee. Execution is paused at the trap-point, and will terminate when resuming execution.
Breakpoint
A breakpoint was hit in the debuggee, pausing execution.
Interrupted
An interruption due to debuggee.interrupt occurred.
CaughtExceptionThrown(Resource<WasmException>)
An exception was thrown and caught by Wasm.
UncaughtExceptionThrown(Resource<WasmException>)
An exception was thrown and not caught by Wasm.
InjectedCallReturn(Vec<Resource<WasmValue>>)
An injected call completed with return value(s).