pub struct Debuggee { /* private fields */ }Expand description
A debuggee consisting of one Store over which we have debugging control.
A debuggee is always either “paused” or “running”, and certain methods below are only available in one or the other state. Representation of one debuggee: a store with debugged code inside, under the control of the debugger.
Implementations