EventFuture

Struct EventFuture 

pub struct EventFuture { /* private fields */ }
A future that represents asynchronous execution of the debuggee until the next debug event pausing execution.

When complete, yields the resulting debug event. Representation of an async debug event that the debugger is waiting on.

Cancel-safety: the non-cancel-safe OpaqueDebugger async methods are called inside an async move block that owns the debugger. ready() merely polls this stored future, which is always safe to re-poll after cancelation. The debugger is returned in the Done state and extracted by finish().