Crate wasmtime_internal_debugger

Crate wasmtime_internal_debugger 

Wasmtime debugger functionality.

This crate builds on top of the core Wasmtime crate’s guest-debugger APIs to present an environment where a debugger runs as a “co-running process” and sees the debuggee as a a provider of a stream of events, on which actions can be taken between each event.

In the future, this crate will also provide a WIT-level API and world in which to run debugger components.

Modules

wit

Structs

Debuggee
A Debuggee wraps up state associated with debugging the code running in a single Store.
DebuggerComponent
Auto-generated bindings for an instance a component which implements the world debug-main.

Enums

DebugRunResult
The result of one call to Debuggee::run().

Functions

add_debuggee
Register a debuggee in a resource table.
add_to_linker
Add the debugger world’s host functions to a wasmtime::component::Linker.