WasmTag

Struct WasmTag 

pub struct WasmTag { /* private fields */ }
A WebAssembly tag.

Implementations

Source

impl Tag

pub fn new(store: impl AsContextMut, ty: &TagType) -> Result<Tag, Error>

Create a new tag instance from a given TagType.

pub fn ty(&self, store: impl AsContext) -> TagType

Returns the underlying type of this tag.

Panics

Panics if store does not own this tag.

pub fn debug_index_in_store(&self) -> u64

Returns a stable identifier for this tag within its store.

This allows distinguishing tags when introspecting them e.g. via debug APIs.

pub fn eq(a: &Tag, b: &Tag, store: impl AsContext) -> bool

Determines whether this tag is reference equal to the other given tag in the given store.

Panics

Panics if either tag do not belong to the given store.