pub struct WasmTag { /* private fields */ }Expand description
A WebAssembly tag.
Implementations
Sourceimpl Tag
impl Tag
Sourcepub fn new(store: impl AsContextMut, ty: &TagType) -> Result<Tag, Error>
pub fn new(store: impl AsContextMut, ty: &TagType) -> Result<Tag, Error>
Create a new tag instance from a given TagType.
Sourcepub fn debug_index_in_store(&self) -> u64
pub fn debug_index_in_store(&self) -> u64
Returns a stable identifier for this tag within its store.
This allows distinguishing tags when introspecting them e.g. via debug APIs.