pub trait HostGlobal: Send {
// Required methods
fn get(
&mut self,
self_: Resource<Global>,
d: Resource<Debuggee>,
) -> impl Future<Output = Result<Resource<WasmValue>, Error>> + Send;
fn set(
&mut self,
self_: Resource<Global>,
d: Resource<Debuggee>,
val: Resource<WasmValue>,
) -> impl Future<Output = Result<(), Error>> + Send;
fn clone(
&mut self,
self_: Resource<Global>,
) -> impl Future<Output = Result<Resource<Global>>> + Send;
fn unique_id(
&mut self,
self_: Resource<Global>,
) -> impl Future<Output = Result<u64>> + Send;
fn drop(
&mut self,
rep: Resource<Global>,
) -> impl Future<Output = Result<()>> + Send;
}Required Methods
Sourcefn get(
&mut self,
self_: Resource<Global>,
d: Resource<Debuggee>,
) -> impl Future<Output = Result<Resource<WasmValue>, Error>> + Send
fn get( &mut self, self_: Resource<Global>, d: Resource<Debuggee>, ) -> impl Future<Output = Result<Resource<WasmValue>, Error>> + Send
Get the value of this global.
Sourcefn set(
&mut self,
self_: Resource<Global>,
d: Resource<Debuggee>,
val: Resource<WasmValue>,
) -> impl Future<Output = Result<(), Error>> + Send
fn set( &mut self, self_: Resource<Global>, d: Resource<Debuggee>, val: Resource<WasmValue>, ) -> impl Future<Output = Result<(), Error>> + Send
Set the value of this global.
Sourcefn clone(
&mut self,
self_: Resource<Global>,
) -> impl Future<Output = Result<Resource<Global>>> + Send
fn clone( &mut self, self_: Resource<Global>, ) -> impl Future<Output = Result<Resource<Global>>> + Send
Clone this handle.
Sourcefn unique_id(
&mut self,
self_: Resource<Global>,
) -> impl Future<Output = Result<u64>> + Send
fn unique_id( &mut self, self_: Resource<Global>, ) -> impl Future<Output = Result<u64>> + Send
Get the unique ID of this memory to allow equality and hashing.
fn drop( &mut self, rep: Resource<Global>, ) -> impl Future<Output = Result<()>> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl HostGlobal for ResourceTable
impl HostGlobal for ResourceTable
async fn get( &mut self, self_: Resource<Global>, d: Resource<Debuggee>, ) -> Result<Resource<WasmValue>>
async fn set( &mut self, self_: Resource<Global>, d: Resource<Debuggee>, val: Resource<WasmValue>, ) -> Result<()>
async fn clone(&mut self, self_: Resource<Global>) -> Result<Resource<Global>>
async fn unique_id(&mut self, self_: Resource<Global>) -> Result<u64>
async fn drop(&mut self, rep: Resource<Global>) -> Result<()>
Sourceimpl<_T: HostGlobal + ?Sized + Send> HostGlobal for &mut _T
impl<_T: HostGlobal + ?Sized + Send> HostGlobal for &mut _T
Sourcefn get(
&mut self,
self_: Resource<Global>,
d: Resource<Debuggee>,
) -> impl Future<Output = Result<Resource<WasmValue>, Error>> + Send
fn get( &mut self, self_: Resource<Global>, d: Resource<Debuggee>, ) -> impl Future<Output = Result<Resource<WasmValue>, Error>> + Send
Get the value of this global.
Sourcefn set(
&mut self,
self_: Resource<Global>,
d: Resource<Debuggee>,
val: Resource<WasmValue>,
) -> impl Future<Output = Result<(), Error>> + Send
fn set( &mut self, self_: Resource<Global>, d: Resource<Debuggee>, val: Resource<WasmValue>, ) -> impl Future<Output = Result<(), Error>> + Send
Set the value of this global.
Sourcefn clone(
&mut self,
self_: Resource<Global>,
) -> impl Future<Output = Result<Resource<Global>>> + Send
fn clone( &mut self, self_: Resource<Global>, ) -> impl Future<Output = Result<Resource<Global>>> + Send
Clone this handle.
Sourcefn unique_id(
&mut self,
self_: Resource<Global>,
) -> impl Future<Output = Result<u64>> + Send
fn unique_id( &mut self, self_: Resource<Global>, ) -> impl Future<Output = Result<u64>> + Send
Get the unique ID of this memory to allow equality and hashing.